@@ -1,6 +1,6 @@
 ;;; treesit-fold-parsers.el --- Adapter layer to Tree-Sitter  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2021-2025  emacs-tree-sitter maintainers
+;; Copyright (C) 2021-2026  emacs-tree-sitter maintainers
 
 ;; Created date 2021-10-04 17:45:48
 
@@ -54,6 +54,9 @@
 (declare-function treesit-fold-range-fish-function "treesit-fold.el")
 (declare-function treesit-fold-range-fish-if "treesit-fold.el")
 (declare-function treesit-fold-range-fish-case "treesit-fold.el")
+(declare-function treesit-fold-range-fsharp-module-defn "treesit-fold.el")
+(declare-function treesit-fold-range-git-config-section "treesit-fold.el")
+(declare-function treesit-fold-range-fsharp-record-type-defn "treesit-fold.el")
 (declare-function treesit-fold-range-haskell-function "treesit-fold.el")
 (declare-function treesit-fold-range-html "treesit-fold.el")
 (declare-function treesit-fold-range-julia-function "treesit-fold.el")
@@ -104,6 +107,7 @@
 (declare-function treesit-fold-range-verilog-initial-construct "treesit-fold.el")
 (declare-function treesit-fold-range-verilog-module "treesit-fold.el")
 (declare-function treesit-fold-range-vhdl-package "treesit-fold.el")
+(declare-function treesit-fold-range-vim-for-loop "treesit-fold.el")
 (declare-function treesit-fold-range-vhdl-type "treesit-fold.el")
 
 ;;
@@ -263,6 +267,14 @@
      . (lambda (node offset)
          (treesit-fold-range-line-comment node offset "%")))))
 
+(defun treesit-fold-parsers-fennel ()
+  "Rules set for Fennel."
+  '((macro_form . treesit-fold-range-elisp-function)
+    (fn_form    . treesit-fold-range-elisp-function)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset ";;")))))
+
 (defun treesit-fold-parsers-fish ()
   "Rules set for Fish."
   '((function_definition . treesit-fold-range-fish-function)
@@ -275,6 +287,14 @@
      . (lambda (node offset)
          (treesit-fold-range-line-comment node offset "#")))))
 
+(defun treesit-fold-parsers-fsharp ()
+  "Rules set for F#."
+  '((module_defn      . treesit-fold-range-fsharp-module-defn)
+    (list_expression  . treesit-fold-range-seq)
+    (record_type_defn . treesit-fold-range-fsharp-record-type-defn)
+    (line_comment     . treesit-fold-range-c-like-comment)
+    (block_comment    . (treesit-fold-range-seq 1 -1))))
+
 (defun treesit-fold-parsers-gdscript ()
   "Rule set for GGScript."
   '((body . (treesit-fold-range-seq -1 1))
@@ -282,6 +302,13 @@
      . (lambda (node offset)
          (treesit-fold-range-line-comment node offset "#")))))
 
+(defun treesit-fold-parsers-git-config ()
+  "Rule set for Git config."
+  '((section . treesit-fold-range-git-config-section)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset "#")))))
+
 (defun treesit-fold-parsers-gleam ()
   "Rules set for Gleam."
   '((function           . treesit-fold-range-gleam)
@@ -545,6 +572,14 @@
   '((body    . treesit-fold-range-seq)
     (comment . treesit-fold-range-c-like-comment)))
 
+(defun treesit-fold-parsers-nim ()
+  "Rule set for Nim."
+  '((array_construction . treesit-fold-range-seq)
+    (for                . treesit-fold-range-seq)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset "#")))))
+
 (defun treesit-fold-parsers-nix ()
   "Rule set for Nix."
   '((attrset_expression . treesit-fold-range-seq)
@@ -760,10 +795,18 @@
     (enumeration_type_definition . treesit-fold-range-seq)
     (comment                     . treesit-fold-range-lua-comment)))
 
-(defun treesit-fold-parsers-vimscript ()
-  "Rule set for Vimscript."
-  '((function_definition . treesit-fold-range-vimscript-function)
-    (if_statement        . (treesit-fold-range-seq 1 -4))))
+(defun treesit-fold-parsers-vim ()
+  "Rule set for Vim."
+  '((function_definition . treesit-fold-range-vim-for-loop)
+    (for_loop            . treesit-fold-range-vim-for-loop)
+    (while_loop          . treesit-fold-range-vim-for-loop)
+    (if_statement        . treesit-fold-range-vim-for-loop)
+    (elseif_statement    . treesit-fold-range-vim-for-loop)
+    (else_statement      . treesit-fold-range-vim-for-loop)
+    (list                . treesit-fold-range-seq)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset "\"")))))
 
 (defun treesit-fold-parsers-xml ()
   "Rule set for XML."
